@@ -27,7 +27,7 @@ elif [ "$KERNEL" = "Linux" ]; then
 	fi
 fi
 
-cd "$BASE_PATH" && java -Djava.library.path=${SERIAL_DRIVER}lib -cp ".:lib:plugins" -jar TunerStudioMS.jar $1
+cd "$BASE_PATH" && java -Dcom.ibm.crypto.provider.DoRSATypeChecking=false -Djava.library.path=${SERIAL_DRIVER}lib -cp ".:lib:plugins" -jar TunerStudioMS.jar $1
 RESULT=$?
 
 if [ -d "$LAST_PATH" ]; then
